aboutsummaryrefslogtreecommitdiff
path: root/mod/profile/icondirect.php
diff options
context:
space:
mode:
authorCash Costello <cash.costello@gmail.com>2011-10-29 09:52:17 -0400
committerCash Costello <cash.costello@gmail.com>2011-10-29 09:52:17 -0400
commit0625897f1e47e6cb46c5e4f4d4b6d50f9dd48239 (patch)
treebcef4565b7c7b4c525d0abda8f2672e11ab8c9f8 /mod/profile/icondirect.php
parent2cbfc4624135475764d6b5a53b0b95fe980793a2 (diff)
downloadelgg-0625897f1e47e6cb46c5e4f4d4b6d50f9dd48239.tar.gz
elgg-0625897f1e47e6cb46c5e4f4d4b6d50f9dd48239.tar.bz2
Fixes #3920 profile plugin adds a fast loading of user avatars
Diffstat (limited to 'mod/profile/icondirect.php')
-rw-r--r--mod/profile/icondirect.php45
1 files changed, 20 insertions, 25 deletions
diff --git a/mod/profile/icondirect.php b/mod/profile/icondirect.php
index fe4726d1a..f7188455e 100644
--- a/mod/profile/icondirect.php
+++ b/mod/profile/icondirect.php
@@ -1,38 +1,33 @@
<?php
-
/**
* Elgg profile icon cache/bypass
*
+ *
* @package ElggProfile
*/
-
// Get DB settings
require_once(dirname(dirname(dirname(__FILE__))). '/engine/settings.php');
global $CONFIG;
-$joindate = (int)$_GET['joindate'];
+$join_date = (int)$_GET['joindate'];
$guid = (int)$_GET['guid'];
$size = strtolower($_GET['size']);
-if (!in_array($size,array('large','medium','small','tiny','master','topbar'))) {
+if (!in_array($size, array('large', 'medium', 'small', 'tiny', 'master', 'topbar'))) {
$size = "medium";
}
-$mysql_dblink = @mysql_connect($CONFIG->dbhost,$CONFIG->dbuser,$CONFIG->dbpass, true);
+$mysql_dblink = @mysql_connect($CONFIG->dbhost, $CONFIG->dbuser, $CONFIG->dbpass, true);
if ($mysql_dblink) {
- if (@mysql_select_db($CONFIG->dbname,$mysql_dblink)) {
-
- // get dataroot and simplecache_enabled in one select for efficiency
- if ($result = mysql_query("select name, value from {$CONFIG->dbprefix}datalists where name in ('dataroot','simplecache_enabled')",$mysql_dblink)) {
- $simplecache_enabled = true;
+ if (@mysql_select_db($CONFIG->dbname, $mysql_dblink)) {
+ $result = mysql_query("select name, value from {$CONFIG->dbprefix}datalists where name='dataroot'", $mysql_dblink);
+ if ($result) {
$row = mysql_fetch_object($result);
while ($row) {
if ($row->name == 'dataroot') {
- $dataroot = $row->value;
- } else if ($row->name == 'simplecache_enabled') {
- $simplecache_enabled = $row->value;
+ $data_root = $row->value;
}
$row = mysql_fetch_object($result);
}
@@ -40,21 +35,22 @@ if ($mysql_dblink) {
@mysql_close($mysql_dblink);
- // if the simplecache is enabled, we get icon directly
- if ($simplecache_enabled) {
+ if (isset($data_root)) {
+
+ // this depends on ElggDiskFilestore::makeFileMatrix()
+ $user_path = date('Y/m/d/', $join_date) . $guid;
- // first try to read icon directly
- $user_path = date('Y/m/d/', $joindate) . $guid;
- $filename = "$dataroot$user_path/profile/{$guid}{$size}.jpg";
+ $filename = "$data_root$user_path/profile/{$guid}{$size}.jpg";
$contents = @file_get_contents($filename);
if (!empty($contents)) {
header("Content-type: image/jpeg");
- header('Expires: ' . date('r',time() + 864000));
+ header('Expires: ' . date('r', strtotime("+6 months")), true);
header("Pragma: public");
header("Cache-Control: public");
header("Content-Length: " . strlen($contents));
- $splitString = str_split($contents, 1024);
- foreach($splitString as $chunk) {
+ // this chunking is done for supposedly better performance
+ $split_string = str_split($contents, 1024);
+ foreach ($split_string as $chunk) {
echo $chunk;
}
exit;
@@ -64,8 +60,7 @@ if ($mysql_dblink) {
}
// simplecache is not turned on or something went wrong so load engine and try that way
require_once(dirname(dirname(dirname(__FILE__))) . "/engine/start.php");
-$user = get_entity($guid);
-set_input('username', $user->username);
-require_once(dirname(__FILE__).'/icon.php');
+elgg_log("Profile icon direct failed.", "WARNING");
+forward("_graphics/icons/user/default{$size}.gif");
@@ -64,8 +60,7 @@ if ($mysql_dblink) {
}
-// simplecache is not turned on or something went wrong so load engine and try that way
+// something went wrong so load engine and try to forward to default icon
require_once(dirname(dirname(dirname(__FILE__))) . "/engine/start.php");